@@ -28,7 +28,6 @@ from plugwise.constants import (
     NONE,
     OFF,
     P1_MEASUREMENTS,
-    PRIORITY_DEVICE_CLASSES,
     TEMP_CELSIUS,
     THERMOSTAT_CLASSES,
     TOGGLES,
@@ -85,11 +84,7 @@ class SmileHelper(SmileCommon):
         self._gateway_id: str = NONE
         self._zones: dict[str, GwEntityData]
         self.gw_entities: dict[str, GwEntityData]
-        self.smile_hw_version: str | None
-        self.smile_mac_address: str | None
-        self.smile_model: str
-        self.smile_model_id: str | None
-        self.smile_version: version.Version
+        self.smile: Munch = Munch()
 
     @property
     def gateway_id(self) -> str:
@@ -160,11 +155,11 @@ class SmileHelper(SmileCommon):
 
             self._create_gw_entities(appl)
 
-        if self.smile_type == "power":
+        if self.smile.type == "power":
             self._get_p1_smartmeter_info()
 
         # Sort the gw_entities
-        self._sort_gw_entities()
+        self._reorder_devices()
 
     def _get_p1_smartmeter_info(self) -> None:
         """For P1 collect the connected SmartMeter info from the Home/building location.
@@ -197,18 +192,6 @@ class SmileHelper(SmileCommon):
 
         self._create_gw_entities(appl)
 
-    def _sort_gw_entities(self) -> None:
-        """Place the gateway and optional heater_central entities as 1st and 2nd."""
-        for dev_class in PRIORITY_DEVICE_CLASSES:
-            for entity_id, entity in dict(self.gw_entities).items():
-                if entity["dev_class"] == dev_class:
-                    priority_entity = entity
-                    self.gw_entities.pop(entity_id)
-                    other_entities = self.gw_entities
-                    priority_entities = {entity_id: priority_entity}
-                    self.gw_entities = {**priority_entities, **other_entities}
-                    break
-
     def _all_locations(self) -> None:
         """Collect all locations."""
         loc = Munch()
@@ -268,16 +251,16 @@ class SmileHelper(SmileCommon):
     def _appl_gateway_info(self, appl: Munch, appliance: etree.Element) -> Munch:
         """Helper-function for _appliance_info_finder()."""
         self._gateway_id = appliance.attrib["id"]
-        appl.firmware = str(self.smile_version)
-        appl.hardware = self.smile_hw_version
-        appl.mac = self.smile_mac_address
-        appl.model = self.smile_model
-        appl.model_id = self.smile_model_id
-        appl.name = self.smile_name
+        appl.firmware = str(self.smile.version)
+        appl.hardware = self.smile.hw_version
+        appl.mac = self.smile.mac_address
+        appl.model = self.smile.model
+        appl.model_id = self.smile.model_id
+        appl.name = self.smile.name
         appl.vendor_name = "Plugwise"
 
         # Adam: collect the ZigBee MAC address of the Smile
-        if self.smile(ADAM):
+        if self.check_name(ADAM):
             if (
                 found := self._domain_objects.find(".//protocols/zig_bee_coordinator")
             ) is not None:
@@ -346,7 +329,7 @@ class SmileHelper(SmileCommon):
         # Get P1 smartmeter data from LOCATIONS
         entity = self.gw_entities[entity_id]
         # !! DON'T CHANGE below two if-lines, will break stuff !!
-        if self.smile_type == "power":
+        if self.smile.type == "power":
             if entity["dev_class"] == "smartmeter":
                 data.update(self._power_data_from_location())
 
@@ -383,7 +366,7 @@ class SmileHelper(SmileCommon):
             data.pop("c_heating_state")
             self._count -= 1
 
-        if self._is_thermostat and self.smile(ANNA):
+        if self._is_thermostat and self.check_name(ANNA):
             self._update_anna_cooling(entity_id, data)
 
         self._cleanup_data(data)
@@ -428,7 +411,8 @@ class SmileHelper(SmileCommon):
                     case "elga_status_code":
                         data["elga_status_code"] = int(appl_p_loc.text)
                     case "select_dhw_mode":
-                        data["select_dhw_mode"] = appl_p_loc.text
+                        if self._dhw_allowed_modes:
+                            data["select_dhw_mode"] = appl_p_loc.text
 
                 common_match_cases(measurement, attrs, appl_p_loc, data)
 
@@ -484,7 +468,7 @@ class SmileHelper(SmileCommon):
                 item == "thermostat"
                 and (
                     entity["dev_class"] != "climate"
-                    if self.smile(ADAM)
+                    if self.check_name(ADAM)
                     else entity["dev_class"] != "thermostat"
                 )
             ):
@@ -539,7 +523,7 @@ class SmileHelper(SmileCommon):
 
         Collect the requested gateway mode.
         """
-        if not (self.smile(ADAM) and entity_id == self._gateway_id):
+        if not (entity_id == self._gateway_id and self.check_name(ADAM)):
             return None
 
         if (search := search_actuator_functionalities(appliance, key)) is not None:
@@ -552,29 +536,31 @@ class SmileHelper(SmileCommon):
     ) -> None:
         """Helper-function for _get_measurement_data().
 
-        Adam: collect the gateway regulation_mode.
+        Adam gateway: collect the gateway regulation_mode.
         """
         if (
             mode := self._get_actuator_mode(
                 appliance, entity_id, "regulation_mode_control_functionality"
             )
         ) is not None:
-            data["select_regulation_mode"] = mode
-            self._count += 1
+            # Below line needs to be here to set the boolean for both older and recent Adam firmware versions
             self._cooling_enabled = mode == "cooling"
+            if self._reg_allowed_modes:
+                data["select_regulation_mode"] = mode
+                self._count += 1
 
     def _get_gateway_mode(
         self, appliance: etree.Element, entity_id: str, data: GwEntityData
     ) -> None:
         """Helper-function for _get_measurement_data().
 
-        Adam: collect the gateway mode.
+        Adam gateway: collect the gateway mode.
         """
         if (
             mode := self._get_actuator_mode(
                 appliance, entity_id, "gateway_mode_control_functionality"
             )
-        ) is not None:
+        ) is not None and self._gw_allowed_modes:
             data["select_gateway_mode"] = mode
             self._count += 1
 
@@ -605,10 +591,10 @@ class SmileHelper(SmileCommon):
 
         Solution for Core issue #81839.
         """
-        if self.smile(ANNA):
+        if self.check_name(ANNA):
             data["binary_sensors"]["heating_state"] = data["c_heating_state"]
 
-        if self.smile(ADAM):
+        if self.check_name(ADAM):
             # First count when not present, then create and init to False.
             # When present init to False
             if "heating_state" not in data["binary_sensors"]:
@@ -723,7 +709,7 @@ class SmileHelper(SmileCommon):
             for entity_id, entity in self.gw_entities.items():
                 self._rank_thermostat(thermo_matching, loc_id, entity_id, entity)
 
-        for loc_id, loc_data in list(self._thermo_locs.items()):
+        for loc_id, loc_data in self._thermo_locs.items():
             if loc_data["primary_prio"] != 0:
                 self._zones[loc_id] = {
                     "dev_class": "climate",
@@ -799,8 +785,8 @@ class SmileHelper(SmileCommon):
 
         # Handle missing control_state in regulation_mode off for firmware >= 3.2.0 (issue #776)
         # In newer firmware versions, default to "off" when control_state is not present
-        if self.smile_version != version.Version("0.0.0"):
-            if self.smile_version >= version.parse("3.2.0"):
+        if self.smile.version != version.Version("0.0.0"):
+            if self.smile.version >= version.parse("3.2.0"):
                 return "off"
 
             # Older Adam firmware does not have the control_state xml-key
