@@ -36,8 +36,8 @@ base = json.load(io)
 adam_multiple_devices_per_zone = base.copy()
 
 # Change schedule to not present for "446ac08dd04d4eff8ac57489757b7314"
-adam_multiple_devices_per_zone["446ac08dd04d4eff8ac57489757b7314"].pop("available_schedules")
-adam_multiple_devices_per_zone["446ac08dd04d4eff8ac57489757b7314"].pop("select_schedule")
+adam_multiple_devices_per_zone["446ac08dd04d4eff8ac57489757b7314"]["available_schedules"] = []
+adam_multiple_devices_per_zone["446ac08dd04d4eff8ac57489757b7314"]["select_schedule"] = None
 
 json_writer("m_adam_multiple_devices_per_zone", adam_multiple_devices_per_zone)
 
@@ -73,24 +73,12 @@ m_adam_cooling.pop("67d73d0bd469422db25a618a5fb8eeb0")
 m_adam_cooling.pop("10016900610d4c7481df78c89606ef22")
 
 # Correct setpoint for device "ad4838d7d35c4d6ea796ee12ae5aedf8" and zone "f2bf9048bef64cc5b6d5110154e33c81"
-m_adam_cooling["ad4838d7d35c4d6ea796ee12ae5aedf8"]["sensors"][
-    "setpoint"
-] = 23.5
-m_adam_cooling["ad4838d7d35c4d6ea796ee12ae5aedf8"]["sensors"][
-    "temperature"
-] = 25.8
-m_adam_cooling["f2bf9048bef64cc5b6d5110154e33c81"]["thermostat"][
-    "setpoint"
-] = 23.5
-m_adam_cooling["f2bf9048bef64cc5b6d5110154e33c81"]["sensors"][
-    "temperature"
-] = 25.8
-m_adam_cooling["f2bf9048bef64cc5b6d5110154e33c81"][
-    "select_schedule"
-] = "off"
-m_adam_cooling["f2bf9048bef64cc5b6d5110154e33c81"][
-    "control_state"
-] = "cooling"
+m_adam_cooling["ad4838d7d35c4d6ea796ee12ae5aedf8"]["sensors"]["setpoint"] = 23.5
+m_adam_cooling["ad4838d7d35c4d6ea796ee12ae5aedf8"]["sensors"]["temperature"] = 25.8
+m_adam_cooling["f2bf9048bef64cc5b6d5110154e33c81"]["thermostat"]["setpoint"] = 23.5
+m_adam_cooling["f2bf9048bef64cc5b6d5110154e33c81"]["sensors"]["temperature"] = 25.8
+m_adam_cooling["f2bf9048bef64cc5b6d5110154e33c81"]["select_schedule"] = "off"
+m_adam_cooling["f2bf9048bef64cc5b6d5110154e33c81"]["control_state"] = "cooling"
 m_adam_cooling["f2bf9048bef64cc5b6d5110154e33c81"]["climate_mode"] = "cool"
 
 # Add new key available
@@ -105,39 +93,23 @@ m_adam_cooling.pop("2568cc4b9c1e401495d4741a5f89bee1")
 m_adam_cooling.pop("854f8a9b0e7e425db97f1f110e1ce4b3")
 
 # Go for 1772
-m_adam_cooling["1772a4ea304041adb83f357b751341ff"]["sensors"][
-    "temperature"
-] = 21.6
+m_adam_cooling["1772a4ea304041adb83f357b751341ff"]["sensors"]["temperature"] = 21.6
 
 # Go for e2f4
-m_adam_cooling["e2f4322d57924fa090fbbc48b3a140dc"]["sensors"][
-    "setpoint"
-] = 23.5
-m_adam_cooling["e2f4322d57924fa090fbbc48b3a140dc"]["sensors"][
-    "temperature"
-] = 23.9
-m_adam_cooling["f871b8c4d63549319221e294e4f88074"]["thermostat"][
-    "setpoint"
-] = 25.0
-m_adam_cooling["f871b8c4d63549319221e294e4f88074"]["sensors"][
-    "temperature"
-] = 23.9
-m_adam_cooling["f871b8c4d63549319221e294e4f88074"][
-    "control_state"
-] = "cooling"
+m_adam_cooling["e2f4322d57924fa090fbbc48b3a140dc"]["sensors"]["setpoint"] = 23.5
+m_adam_cooling["e2f4322d57924fa090fbbc48b3a140dc"]["sensors"]["temperature"] = 23.9
+m_adam_cooling["f871b8c4d63549319221e294e4f88074"]["thermostat"]["setpoint"] = 25.0
+m_adam_cooling["f871b8c4d63549319221e294e4f88074"]["sensors"]["temperature"] = 23.9
+m_adam_cooling["f871b8c4d63549319221e294e4f88074"]["control_state"] = "cooling"
 m_adam_cooling["f871b8c4d63549319221e294e4f88074"]["climate_mode"] = "auto"
 
 
 # Go for da22
-m_adam_cooling["da224107914542988a88561b4452b0f6"][
-    "select_regulation_mode"
-] = "cooling"
-m_adam_cooling["da224107914542988a88561b4452b0f6"][
-    "regulation_modes"
-].append("cooling")
-m_adam_cooling["da224107914542988a88561b4452b0f6"]["sensors"][
-    "outdoor_temperature"
-] = 29.65
+m_adam_cooling["da224107914542988a88561b4452b0f6"]["select_regulation_mode"] = "cooling"
+m_adam_cooling["da224107914542988a88561b4452b0f6"]["regulation_modes"].append("cooling")
+m_adam_cooling["da224107914542988a88561b4452b0f6"]["sensors"]["outdoor_temperature"] = (
+    29.65
+)
 
 # Go for 056e
 m_adam_cooling["056ee145a816487eaa69243c3280f8bf"]["binary_sensors"][
@@ -146,12 +118,12 @@ m_adam_cooling["056ee145a816487eaa69243c3280f8bf"]["binary_sensors"][
 m_adam_cooling["056ee145a816487eaa69243c3280f8bf"]["binary_sensors"][
     "heating_state"
 ] = False
-m_adam_cooling["056ee145a816487eaa69243c3280f8bf"]["binary_sensors"][
-    "flame_state"
-] = False
-m_adam_cooling["056ee145a816487eaa69243c3280f8bf"]["sensors"][
-    "water_temperature"
-] = 19.0
+m_adam_cooling["056ee145a816487eaa69243c3280f8bf"]["binary_sensors"]["flame_state"] = (
+    False
+)
+m_adam_cooling["056ee145a816487eaa69243c3280f8bf"]["sensors"]["water_temperature"] = (
+    19.0
+)
 m_adam_cooling["056ee145a816487eaa69243c3280f8bf"]["sensors"][
     "intended_boiler_temperature"
 ] = 17.5
@@ -163,56 +135,30 @@ json_writer("m_adam_cooling", m_adam_cooling)
 m_adam_heating = m_adam_cooling.copy()
 
 # Correct setpoint for "ad4838d7d35c4d6ea796ee12ae5aedf8"
-m_adam_heating["f2bf9048bef64cc5b6d5110154e33c81"]["thermostat"][
-    "setpoint"
-] = 20.0
-m_adam_heating["ad4838d7d35c4d6ea796ee12ae5aedf8"]["sensors"][
-    "setpoint"
-] = 20.0
-m_adam_heating["f2bf9048bef64cc5b6d5110154e33c81"]["sensors"][
-    "temperature"
-] = 19.1
-m_adam_heating["ad4838d7d35c4d6ea796ee12ae5aedf8"]["sensors"][
-    "temperature"
-] = 19.1
+m_adam_heating["f2bf9048bef64cc5b6d5110154e33c81"]["thermostat"]["setpoint"] = 20.0
+m_adam_heating["ad4838d7d35c4d6ea796ee12ae5aedf8"]["sensors"]["setpoint"] = 20.0
+m_adam_heating["f2bf9048bef64cc5b6d5110154e33c81"]["sensors"]["temperature"] = 19.1
+m_adam_heating["ad4838d7d35c4d6ea796ee12ae5aedf8"]["sensors"]["temperature"] = 19.1
 
-m_adam_heating["f2bf9048bef64cc5b6d5110154e33c81"][
-    "control_state"
-] = "preheating"
+m_adam_heating["f2bf9048bef64cc5b6d5110154e33c81"]["control_state"] = "preheating"
 m_adam_heating["f2bf9048bef64cc5b6d5110154e33c81"]["climate_mode"] = "heat"
 
 # Go for 1772
-m_adam_heating["1772a4ea304041adb83f357b751341ff"]["sensors"][
-    "temperature"
-] = 18.6
+m_adam_heating["1772a4ea304041adb83f357b751341ff"]["sensors"]["temperature"] = 18.6
 # Related zone temperature is set below
 
 # Go for e2f4
-m_adam_heating["f871b8c4d63549319221e294e4f88074"]["thermostat"][
-    "setpoint"
-] = 15.0
-m_adam_heating["e2f4322d57924fa090fbbc48b3a140dc"]["sensors"][
-    "setpoint"
-] = 15.0
-m_adam_heating["f871b8c4d63549319221e294e4f88074"]["sensors"][
-    "temperature"
-] = 17.9
-m_adam_heating["e2f4322d57924fa090fbbc48b3a140dc"]["sensors"][
-    "temperature"
-] = 17.9
+m_adam_heating["f871b8c4d63549319221e294e4f88074"]["thermostat"]["setpoint"] = 15.0
+m_adam_heating["e2f4322d57924fa090fbbc48b3a140dc"]["sensors"]["setpoint"] = 15.0
+m_adam_heating["f871b8c4d63549319221e294e4f88074"]["sensors"]["temperature"] = 17.9
+m_adam_heating["e2f4322d57924fa090fbbc48b3a140dc"]["sensors"]["temperature"] = 17.9
 
 m_adam_heating["f871b8c4d63549319221e294e4f88074"]["climate_mode"] = "auto"
-m_adam_heating["f871b8c4d63549319221e294e4f88074"][
-    "control_state"
-] = "idle"
+m_adam_heating["f871b8c4d63549319221e294e4f88074"]["control_state"] = "idle"
 
 # Go for da22
-m_adam_heating["da224107914542988a88561b4452b0f6"][
-    "select_regulation_mode"
-] = "heating"
-m_adam_heating["da224107914542988a88561b4452b0f6"][
-    "regulation_modes"
-].remove("cooling")
+m_adam_heating["da224107914542988a88561b4452b0f6"]["select_regulation_mode"] = "heating"
+m_adam_heating["da224107914542988a88561b4452b0f6"]["regulation_modes"].remove("cooling")
 m_adam_heating["da224107914542988a88561b4452b0f6"]["sensors"][
     "outdoor_temperature"
 ] = -1.25
@@ -224,12 +170,12 @@ m_adam_heating["056ee145a816487eaa69243c3280f8bf"]["binary_sensors"].pop(
 m_adam_heating["056ee145a816487eaa69243c3280f8bf"]["binary_sensors"][
     "heating_state"
 ] = True
-m_adam_heating["056ee145a816487eaa69243c3280f8bf"]["binary_sensors"][
-    "flame_state"
-] = False
-m_adam_heating["056ee145a816487eaa69243c3280f8bf"]["sensors"][
-    "water_temperature"
-] = 37.0
+m_adam_heating["056ee145a816487eaa69243c3280f8bf"]["binary_sensors"]["flame_state"] = (
+    False
+)
+m_adam_heating["056ee145a816487eaa69243c3280f8bf"]["sensors"]["water_temperature"] = (
+    37.0
+)
 m_adam_heating["056ee145a816487eaa69243c3280f8bf"]["sensors"][
     "intended_boiler_temperature"
 ] = 38.1
@@ -252,18 +198,18 @@ base = json.load(io)
 m_anna_heatpump_cooling = base.copy()
 
 # Go for 1cbf
-m_anna_heatpump_cooling["1cbf783bb11e4a7c8a6843dee3a86927"][
-    "model"
-] = "Generic heater/cooler"
-m_anna_heatpump_cooling["1cbf783bb11e4a7c8a6843dee3a86927"][
-    "binary_sensors"
-]["cooling_enabled"] = True
-m_anna_heatpump_cooling["1cbf783bb11e4a7c8a6843dee3a86927"][
-    "binary_sensors"
-]["heating_state"] = False
-m_anna_heatpump_cooling["1cbf783bb11e4a7c8a6843dee3a86927"][
-    "binary_sensors"
-]["cooling_state"] = True
+m_anna_heatpump_cooling["1cbf783bb11e4a7c8a6843dee3a86927"]["model"] = (
+    "Generic heater/cooler"
+)
+m_anna_heatpump_cooling["1cbf783bb11e4a7c8a6843dee3a86927"]["binary_sensors"][
+    "cooling_enabled"
+] = True
+m_anna_heatpump_cooling["1cbf783bb11e4a7c8a6843dee3a86927"]["binary_sensors"][
+    "heating_state"
+] = False
+m_anna_heatpump_cooling["1cbf783bb11e4a7c8a6843dee3a86927"]["binary_sensors"][
+    "cooling_state"
+] = True
 
 m_anna_heatpump_cooling["1cbf783bb11e4a7c8a6843dee3a86927"]["sensors"][
     "water_temperature"
@@ -344,9 +290,9 @@ m_anna_heatpump_idle["1cbf783bb11e4a7c8a6843dee3a86927"]["sensors"][
 
 # Go for 3cb7
 m_anna_heatpump_idle["3cb70739631c4d17a86b8b12e8a5161b"]["control_state"] = "idle"
-m_anna_heatpump_idle["3cb70739631c4d17a86b8b12e8a5161b"]["sensors"][
-    "temperature"
-] = 23.0
+m_anna_heatpump_idle["3cb70739631c4d17a86b8b12e8a5161b"]["sensors"]["temperature"] = (
+    23.0
+)
 m_anna_heatpump_idle["3cb70739631c4d17a86b8b12e8a5161b"]["sensors"][
     "cooling_activation_outdoor_temperature"
 ] = 25.0
